@@ -5,7 +5,7 @@
  *
  * See http://mod-qos.sourceforge.net/ for further details.
  *
- * Copyright (C) 2018 Pascal Buchbinder
+ * Copyright (C) 2020 Pascal Buchbinder
  *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
@@ -24,7 +24,7 @@
  *
  */
 
-static const char revision[] = "$Id: qsexec.c 2486 2018-09-03 20:22:17Z pbuchbinder $";
+static const char revision[] = "$Id: qsexec.c 2595 2020-01-03 06:19:53Z pbuchbinder $";
 
 /* system */
 #include <stdio.h>
@@ -131,7 +131,7 @@ static void usage(char *cmd, int man) {
   qs_man_print(man, "client causing a mod_qos(031) messages whenever the log message\n");
   qs_man_print(man, "appears 10 times within at most one minute:\n");
   if(man) printf("\n");
-  qs_man_println(man, "  ErrorLog \"|%s -e \\'mod_qos\\(031\\).*, c=([0-9a-zA-Z:.]*)\\' -t 10:60 \\'/bin/deny.sh $1\\'\"\n", cmd);
+  qs_man_println(man, "  ErrorLog \"|/usr/bin/%s -e \\'mod_qos\\(031\\).*, c=([0-9a-zA-Z:.]*)\\' -t 10:60 \\'/usr/local/bin/deny.sh $1\\'\"\n", cmd);
   printf("\n");
   if(man) {
     printf(".SH SEE ALSO\n");
