@@ -7,7 +7,7 @@
  *
  * See http://mod-qos.sourceforge.net/ for further details.
  *
- * Copyright (C) 2018 Pascal Buchbinder
+ * Copyright (C) 2020 Pascal Buchbinder
  *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
@@ -26,7 +26,7 @@
  *
  */
 
-static const char revision[] = "$Id: qsgrep.c 2480 2018-08-27 20:20:04Z pbuchbinder $";
+static const char revision[] = "$Id: qsgrep.c 2595 2020-01-03 06:19:53Z pbuchbinder $";
 
 /* system */
 #include <stdio.h>
@@ -121,7 +121,7 @@ static void usage(char *cmd, int man) {
   printf("\n");
   if(man) {
     printf(".SH SEE ALSO\n");
-    printf("qsdt(1), qsexec(1), qsfilter2(1), qsgeo(1), qshead(1), qslog(1), qslogger(1), qspng(1), qsrotate(1), qssign(1), qstail(1)\n");
+    printf("qsdt(1), qsexec(1), qsfilter2(1), qsgeo(1), qshead(1), qslog(1), qslogger(1), qspng(1), qsre(1), qsrespeed(1), qsrotate(1), qssign(1), qstail(1)\n");
     printf(".SH AUTHOR\n");
     printf("Pascal Buchbinder, http://mod-qos.sourceforge.net/\n");
   } else {
